@@ -5,7 +5,7 @@ from django.core.cache.backends.base import DEFAULT_TIMEOUT, BaseCache
 
 class DummyCache(BaseCache):
     def __init__(self, host, *args, **kwargs):
-        BaseCache.__init__(self, *args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def add(self, key, value, timeout=DEFAULT_TIMEOUT, version=None):
         key = self.make_key(key, version=version)
@@ -21,23 +21,19 @@ class DummyCache(BaseCache):
         key = self.make_key(key, version=version)
         self.validate_key(key)
 
+    def touch(self, key, timeout=DEFAULT_TIMEOUT, version=None):
+        self.validate_key(key)
+        return False
+
     def delete(self, key, version=None):
         key = self.make_key(key, version=version)
         self.validate_key(key)
-
-    def get_many(self, keys, version=None):
-        return {}
+        return False
 
     def has_key(self, key, version=None):
         key = self.make_key(key, version=version)
         self.validate_key(key)
         return False
 
-    def set_many(self, data, timeout=DEFAULT_TIMEOUT, version=None):
-        return []
-
-    def delete_many(self, keys, version=None):
-        pass
-
     def clear(self):
         pass
